@@ -11,8 +11,7 @@
 # GNU Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 """Python API to Speech Dispatcher
 
@@ -851,7 +850,7 @@ class SSIPClient(object):
         except SSIPCommandError:
             return ()
         def split(item):
-            name, lang, dialect = tuple(item.rsplit(' ', 3))
+            name, lang, dialect = tuple(item.rsplit('\t', 3))
             return (name, lang or None, dialect or None)
         return tuple([split(item) for item in data])
 
@@ -911,6 +910,20 @@ class SSIPClient(object):
             return data[0]
         return None
 
+    def set_pitch_range(self, value, scope=Scope.SELF):
+        """Set the pitch range for further speech commands.
+
+        Arguments:
+          value -- integer value within the range from -100 to 100, with 0
+            corresponding to the default pitch range of the current speech synthesis
+            output module, lower values meaning lower pitch range and higher values
+            meaning higher pitch range.
+          scope -- see the documentation of this class.
+          
+        """
+        assert isinstance(value, int) and -100 <= value <= 100, value
+        self._conn.send_command('SET', scope, 'PITCH_RANGE', value)
+
     def set_rate(self, value, scope=Scope.SELF):
         """Set the speech rate (speed) for further speech commands.
 
